pub struct UpdateReport { /* private fields */ }Expand description
Exact changes made by one atomic update batch.
Implementations
Sourceimpl UpdateReport
impl UpdateReport
pub fn changes(&self) -> &[UpdateChange]
Sourcepub const fn connectivity_changed(&self) -> bool
pub const fn connectivity_changed(&self) -> bool
True only when a changed branch service flag or switch position changes which terminal pairs are electrically connected.
pub fn is_empty(&self) -> bool